﻿//********************************************************************************
//**
//**  Titel           : 
//**  Name            : WadExport.vb
//**  Typ             : DLL
//**  Copyright       : (c)2016 Christian Meyer
//**
//**  Beschreibung    : WinAlldatNet KIS Export DLL
//**
//**  Autor           : Christian Meyer
//**  Datum           : 17.12.2016
//**  Letzte Revision : 05.05.2022
//**  Status          : Konvertierung von WadExport.vb
//**  Änderungen      : Neue Felder: kiscaseid, fallid; Änderung Zielframework 2.0 -> 6.0
//**
//********************************************************************************
using System;
using System.Diagnostics;
using System.Windows.Forms;

public class WadExport

{
    //**************************************************************************************************
    //* WICHTIG: Funktioniert erst ab WinAlldatNet Release 19 !
    //**************************************************************************************************

    //**************************************************************************************************
    //* Zielframework .NET 6.0 WICHTIG: Unterverzeichnis für Archivschnittstelle muss existent sein
    //**************************************************************************************************

    public struct ExportData
    {
        public int ipatid; //WinAlldat Patienten-ID; WICHTIG: alte DLL-Versionen mappen hier die WinAlldat Fall-ID!!!
        public int fallid; //WinAlldat Fall-ID; Neu hinzugekommen!
        public string adminid;  //KIS Patienten-ID (ehemalige Stamm-Nr.)
        public string kiscaseid; //KIS Fall-Id; Neu hinzugekommen!
        public string patname;
        public string patfirstname;
        public string birthname;
        public string birthdate;
        public string sex;
        public string street;
        public string zipcode;
        public string city;
        public string country;
        public string phone_work;
        public string phone_athome;
        public string datecurrent;
        public string dateconsultation;
        public string documentname;
        public string documentpath; //Dateipfad ohne Dateinamen
        public string documentfullpath; //Dateipfad mit Dateinamen
        public string documentformat; //TXT, PDF, XML, HTML
        public string documenttype; //TestProtocol, FindingsProtocol
    }

    //********************************************************************************
    //*
    //********************************************************************************

    private ExportData oData;
    public ExportData Data
    {
        get { return oData; }
        set { oData = value; }
    }

    //********************************************************************************
    //*
    //********************************************************************************

    public bool Send(ExportData oData)
    {
        try
        {
            // KIS Fall-ID oder KIS Patienten-ID leer -> Fehlerausgabe und PDF-Datei löschen
            if (string.IsNullOrEmpty(oData.kiscaseid) || string.IsNullOrEmpty(oData.adminid))
            {
                string sErrorCaption = "HL7-Nachricht konnte nicht generiert werden";
                if (string.IsNullOrEmpty(oData.kiscaseid) & string.IsNullOrEmpty(oData.adminid))
                {
                    MessageBox.Show("Keine KIS Fall-ID und KIS Patienten-ID eingegeben!", sErrorCaption, MessageBoxButtons.OK, MessageBoxIcon.Error);
                }
                else if (string.IsNullOrEmpty(oData.kiscaseid))
                {
                    MessageBox.Show("Keine KIS Fall-ID eingegeben!", sErrorCaption, MessageBoxButtons.OK, MessageBoxIcon.Error);
                }
                else if (string.IsNullOrEmpty(oData.adminid))
                {
                    MessageBox.Show("Keine KIS Patienten-ID eingegeben!", sErrorCaption, MessageBoxButtons.OK, MessageBoxIcon.Error);
                }
                System.IO.File.Delete(oData.documentfullpath);
                return false;
            }
            // HL7 Nachricht generieren
            else
            {
                string sFileName = oData.fallid + "_" + oData.kiscaseid + "_" + oData.adminid + "_Testprotokoll_IVDK_T";
                string sDateTime = DateTime.Now.ToString("yyyyMMddHHmmss");
                string sText = "";
                sText += "MSH|^~\\&|IVDK|ALLERGO|Pegasos|Archiv|" + sDateTime + "||MDM^T02|" + oData.fallid + "-" + oData.kiscaseid + "|T|2.3|||||||" + Environment.NewLine;
                sText += "PID|||" + oData.adminid + "|" + oData.kiscaseid + "|";
                sText += oData.patname + "^" + oData.patfirstname + "||" + oData.birthdate + "000000||";
                sText += oData.sex + "|||||||||||" + Environment.NewLine;
                sText += "PV1|1|I|^^^ALLERGO||||||||||||||||" + oData.kiscaseid + "|" + Environment.NewLine;
                sText += "TXA|1|1099|LNK|||" + sDateTime + "|" + sDateTime + "|||||" + oData.fallid + "-" + oData.kiscaseid + "||||";
                sText += oData.documentfullpath + "|IVDK|" + Environment.NewLine;
                sText += "OBX|1|RP|||" + oData.documentfullpath + "|||||||||" + Environment.NewLine;

                WriteStringToFile(System.IO.Path.Combine(oData.documentpath, sFileName + ".txt"), sText);
                return true;
            }
        }
        catch
        {
            return false;
        }
    }

    //********************************************************************************
    //*
    //********************************************************************************

    private string GetBaseDirectory()
    {
        try
        {
            return System.IO.Path.GetDirectoryName(Process.GetCurrentProcess().MainModule.FileName);
        }
        catch
        {
            return "";
        }
    }

    //********************************************************************************
    //*
    //********************************************************************************

    private bool WriteStringToFile(string sFileName, string sText)
    {
        if (System.IO.File.Exists(sFileName) == true)
        {
            System.IO.File.Delete(sFileName);
        }

        System.IO.StreamWriter oStreamWriter = new System.IO.StreamWriter(sFileName, true, System.Text.Encoding.Default);

        oStreamWriter.Write(sText);
        oStreamWriter.Flush();
        oStreamWriter.Close();
        return true;
    }

}


